==> morel-0.3.0-source-release.zip: morel-0.3.0/src/main/java/net/hydromatic/morel/util/ComparableSingletonList.java <==
/*
 * Licensed to Julian Hyde under one or more contributor license
 * agreements.  See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Julian Hyde licenses this file to you under the Apache
 * License, Version 2.0 (the "License"); you may not use this
 * file except in compliance with the License.  You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.  See the License for the specific
 * language governing permissions and limitations under the
 * License.
 */
package net.hydromatic.morel.util;

import java.util.AbstractList;
import java.util.Objects;

/** A comparable singleton list.
 *
 * @param <E> Element type */
public class ComparableSingletonList<E extends Comparable<E>>
    extends AbstractList<E>
    implements Comparable<ComparableSingletonList<E>> {
  private final E element;

  ComparableSingletonList(E element) {
    this.element = Objects.requireNonNull(element);
  }

  /** Creates a ComparableSingletonList. */
  public static <E extends Comparable<E>> ComparableSingletonList<E> of(E e) {
    return new ComparableSingletonList<>(e);
  }

  @Override public E get(int index) {
    assert index == 0;
    return element;
  }

  @Override public int size() {
    return 1;
  }

  @Override public int compareTo(ComparableSingletonList<E> o) {
    return element.compareTo(o.element);
  }
}

// End ComparableSingletonList.java

==> morel-0.5.0-source-release.zip: morel-0.5.0/src/main/java/net/hydromatic/morel/util/ComparableSingletonList.java <==
/*
 * Licensed to Julian Hyde under one or more contributor license
 * agreements.  See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Julian Hyde licenses this file to you under the Apache
 * License, Version 2.0 (the "License"); you may not use this
 * file except in compliance with the License.  You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.  See the License for the specific
 * language governing permissions and limitations under the
 * License.
 */
package net.hydromatic.morel.util;

import java.util.AbstractList;

import static java.util.Objects.requireNonNull;

/** A comparable singleton list.
 *
 * @param <E> Element type */
public class ComparableSingletonList<E extends Comparable<E>>
    extends AbstractList<E>
    implements Comparable<ComparableSingletonList<E>> {
  private final E element;

  ComparableSingletonList(E element) {
    this.element = requireNonNull(element);
  }

  /** Creates a ComparableSingletonList. */
  public static <E extends Comparable<E>> ComparableSingletonList<E> of(E e) {
    return new ComparableSingletonList<>(e);
  }

  @Override public E get(int index) {
    assert index == 0;
    return element;
  }

  @Override public int size() {
    return 1;
  }

  @Override public int compareTo(ComparableSingletonList<E> o) {
    return element.compareTo(o.element);
  }
}

// End ComparableSingletonList.java
